@@ -9,7 +9,8 @@ if not modules then modules = { } end modules ['mtx-patterns'] = {
 local format, find, concat, gsub, match, gmatch = string.format, string.find, table.concat, string.gsub, string.match, string.gmatch
 local byte, char = utf.byte, utf.char
 local addsuffix = file.addsuffix
-local lpegmatch, validutf8 = lpeg.match, lpeg.patterns.validutf8
+local lpegmatch, lpegsplit, lpegpatterns, validutf8 = lpeg.match, lpeg.split, lpeg.patterns, lpeg.patterns.validutf8
+local P, V, Cs = lpeg.P, lpeg.V, lpeg.Cs
 
 local helpinfo = [[
 <?xml version="1.0"?>
@@ -29,6 +30,7 @@ local helpinfo = [[
     <flag name="specification"><short>additional patterns: e.g.: =cy,hyph-cy,welsh</short></flag>
     <flag name="compress"><short>compress data</short></flag>
     <flag name="words"><short>update words in given file</short></flag>
+    <flag name="hyphenate"><short>show hypephenated words</short></flag>
    </subcategory>
   </category>
  </flags>
@@ -40,6 +42,7 @@ local helpinfo = [[
     <example><command>mtxrun --script pattern --check   --path=c:/data/develop/svn-hyphen/trunk/hyph-utf8/tex/generic/hyph-utf8/patterns</command></example>
     <example><command>mtxrun --script pattern --convert --path=c:/data/develop/svn-hyphen/trunk/hyph-utf8/tex/generic/hyph-utf8/patterns/tex --destination=e:/tmp/patterns</command></example>
     <example><command>mtxrun --script pattern --convert --path=c:/data/develop/svn-hyphen/trunk/hyph-utf8/tex/generic/hyph-utf8/patterns/txt --destination=e:/tmp/patterns</command></example>
+    <example><command>mtxrun --script pattern --hyphenate --language=nl --left=3 nogalwiedes inderdaad</command></example>
    </subcategory>
   </category>
  </examples>
@@ -103,7 +106,7 @@ scripts.patterns.list = {
  -- { "gr",  "hyph-el-polyton",    "greek" },
     { "agr", "hyph-grc",           "ancient greek", ignored_ancient_greek },
     { "gb",  "hyph-en-gb",         "british english" },
-    { "us",  "hyph-en-us",	       "american english" },
+    { "us",  "hyph-en-us",         "american english" },
  -- { "eo",  "hyph-eo",            "esperanto" },
     { "es",  "hyph-es",            "spanish" },
     { "et",  "hyph-et",            "estonian" },
@@ -126,6 +129,7 @@ scripts.patterns.list = {
  -- { "??",  "hyph-kmr",           "kurmanji" },
  -- { "kn",  "hyph-kn",            "kannada" },
     { "la",  "hyph-la",            "latin" },
+    { "ala", "hyph-la-x-classic",  "ancient latin" },
  -- { "lo",  "hyph-lo",            "lao" },
     { "lt",  "hyph-lt",            "lithuanian" },
     { "lv",  "hyph-lv",            "latvian" },
@@ -162,7 +166,7 @@ scripts.patterns.list = {
 local utf = unicode.utf8
 
 function utf.check(str)
-    return lpeg.match(lpeg.patterns.validutf8,str)
+    return lpegmatch(lpegpatterns.validutf8,str)
 end
 
 -- *.tex
@@ -211,9 +215,9 @@ function scripts.patterns.load(path,name,mnemonic,ignored)
     end
     if okay then
         -- split into lines
-        local how = lpeg.patterns.whitespace^1
-        splitpatternsnew = lpeg.split(how,patterns)
-        splithyphenationsnew = lpeg.split(how,hyphenations)
+        local how = lpegpatterns.whitespace^1
+        splitpatternsnew = lpegsplit(how,patterns)
+        splithyphenationsnew = lpegsplit(how,hyphenations)
     end
     if okay then
         -- remove comments
@@ -313,23 +317,23 @@ function scripts.patterns.load(path,name,mnemonic,ignored)
             if ignored then
                 for k, v in next, ignored do
                     if p then
-                        p = p + lpeg.P(char(k))
+                        p = p + P(char(k))
                     else
-                        p = lpeg.P(char(k))
+                        p = P(char(k))
                     end
                 end
-                p = lpeg.P{ p + 1 * lpeg.V(1) } -- anywhere
+                p = P{ p + 1 * V(1) } -- anywhere
             end
             -- replaced (all languages)
             local r = nil
             for k, v in next, replaced_whatever do
                 if r then
-                    r = r + lpeg.P(k)/v
+                    r = r + P(k)/v
                 else
-                    r = lpeg.P(k)/v
+                    r = P(k)/v
                 end
             end
-            r = lpeg.Cs((r + 1)^0)
+            r = Cs((r + 1)^0)
             local result = { }
             for i=1,#what do
                 local line = what[i]
@@ -438,13 +442,13 @@ function scripts.patterns.save(destination,mnemonic,name,patternsnew,hyphenation
         if nofpatternsnew > 0 then
             local data = concat(patternsnew," ")
             patterndata = {
-                n            = nofpatternsnew,
-                compression  = compression,
-                length       = #data,
-                data         = compression and zlib.compress(data,9) or data,
-                characters   = concat(table.sortedkeys(pusednew),""),
-                minhyphenmin = 1, -- determined by pattern author
-                minhyphenmax = 1, -- determined by pattern author
+                n              = nofpatternsnew,
+                compression    = compression,
+                length         = #data,
+                data           = compression and zlib.compress(data,9) or data,
+                characters     = concat(table.sortedkeys(pusednew),""),
+                lefthyphenmin  = 1, -- determined by pattern author
+                righthyphenmax = 1, -- determined by pattern author
             }
         else
             patterndata = {
@@ -625,6 +629,49 @@ function scripts.patterns.words()
     end
 end
 
+-- mtxrun --script patterns --hyphenate --language=nl nogalwiedes --left=3
+--
+-- hyphenator      |
+-- hyphenator      | . n o g a l w i e d e s .         . n o g a l w i e d e s .
+-- hyphenator      | .0n4                               0 4 0 0 0 0 0 0 0 0 0 0
+-- hyphenator      |    0o0g0a4l0                       0 4 0 0 4 0 0 0 0 0 0 0
+-- hyphenator      |      1g0a0                         0 4 1 0 4 0 0 0 0 0 0 0
+-- hyphenator      |          0l1w0                     0 4 1 0 4 1 0 0 0 0 0 0
+-- hyphenator      |              4i0e0                 0 4 1 0 4 1 4 0 0 0 0 0
+-- hyphenator      |              0i0e3d0e0             0 4 1 0 4 1 4 0 3 0 0 0
+-- hyphenator      |                0e1d0               0 4 1 0 4 1 4 0 3 0 0 0
+-- hyphenator      |                  1d0e0             0 4 1 0 4 1 4 0 3 0 0 0
+-- hyphenator      |                  0d0e2s0           0 4 1 0 4 1 4 0 3 0 2 0
+-- hyphenator      |                      4s0.          0 4 1 0 4 1 4 0 3 0 4 0
+-- hyphenator      | .0n4o1g0a4l1w4i0e3d0e4s0.         . n o-g a l-w i e-d e s .
+-- hyphenator      |
+-- mtx-patterns    | nl 3 3 : nogalwiedes : nogal-wie-des
+
+function scripts.patterns.hyphenate()
+    require("lang-hyp")
+    local traditional   = languages.hyphenators.traditional
+    local left          = tonumber(environment.arguments.left)  or 3
+    local right         = tonumber(environment.arguments.right) or 3
+    local language      = environment.arguments.language or "us"
+    local dictionary    = traditional.loadpatterns(language)
+    local words         = environment.files
+    local specification = {
+        leftcharmin     = left,
+        rightcharmin    = right,
+        leftchar        = false,
+        rightchar       = false,
+    }
+    trackers.enable("hyphenator.steps")
+    for i=1,#words do
+        local word = words[i]
+        report("%s %s %s : %s : %s",
+            language, left, right,
+            word,
+            traditional.injecthyphens(dictionary,word,specification)
+        )
+    end
+end
+
 if environment.argument("check") then
     scripts.patterns.prepare()
     scripts.patterns.check()
@@ -633,16 +680,21 @@ elseif environment.argument("convert") then
     scripts.patterns.convert()
 elseif environment.argument("words") then
     scripts.patterns.words() -- for the moment here
+elseif environment.argument("hyphenate") then
+    scripts.patterns.hyphenate() -- for the moment here
 elseif environment.argument("exporthelp") then
     application.export(environment.argument("exporthelp"),environment.files[1])
 else
     application.help()
 end
 
--- mtxrun --script pattern --check hyph-*.tex
--- mtxrun --script pattern --check          --path=c:/data/develop/svn-hyphen/trunk/hyph-utf8/tex/generic/hyph-utf8/patterns
--- mtxrun --script pattern --convert        --path=c:/data/develop/svn-hyphen/trunk/hyph-utf8/tex/generic/hyph-utf8/patterns/tex --destination=e:/tmp/patterns
--- mtxrun --script pattern --convert        --path=c:/data/develop/svn-hyphen/trunk/hyph-utf8/tex/generic/hyph-utf8/patterns/txt --destination=e:/tmp/patterns
+-- mtxrun --script pattern --check   hyph-*.tex
+-- mtxrun --script pattern --check   --path=c:/data/develop/svn-hyphen/trunk/hyph-utf8/tex/generic/hyph-utf8/patterns
+-- mtxrun --script pattern --convert --path=c:/data/develop/svn-hyphen/trunk/hyph-utf8/tex/generic/hyph-utf8/patterns/tex --destination=e:/tmp/patterns
+--
+-- use this call:
+--
+-- mtxrun --script pattern --convert --path=c:/data/develop/svn-hyphen/trunk/hyph-utf8/tex/generic/hyph-utf8/patterns/txt --destination=e:/tmp/patterns
 
 -- copy /Y *.hyp e:\tex-context\tex\texmf-context\tex\context\patterns
 -- copy /Y *.pat e:\tex-context\tex\texmf-context\tex\context\patterns
